@@ -13,12 +13,10 @@ def read_fixture(path):
 
 @pytest.fixture
 def book_list_html():
-    return read_fixture('fixtures/book_list.html')
+    return read_fixture("fixtures/book_list.html")
 
 
 @pytest.fixture
 def book_list_html_response(book_list_html):
     body = HttpResponseBody(bytes(book_list_html, "utf-8"))
-    return HttpResponse(
-        url='http://books.toscrape.com/index.html', body=body, encoding="utf-8"
-    )
+    return HttpResponse(url="http://books.toscrape.com/index.html", body=body, encoding="utf-8")
