@@ -1,7 +1,7 @@
 import pytest
 
 from web_poet.mixins import ResponseShortcutsMixin
-from web_poet.page_inputs import HttpResponse, HttpResponseBody
+from web_poet.page_inputs import HttpResponse
 
 
 class MyPage(ResponseShortcutsMixin):
@@ -16,7 +16,7 @@ def my_page(book_list_html_response):
 
 
 def test_url(my_page):
-    assert my_page.url == 'http://books.toscrape.com/index.html'
+    assert my_page.url == "http://books.toscrape.com/index.html"
 
 
 def test_html(my_page, book_list_html):
@@ -24,21 +24,21 @@ def test_html(my_page, book_list_html):
 
 
 def test_xpath(my_page):
-    title = my_page.xpath('.//title/text()').get().strip()
-    assert title == 'All products | Books to Scrape - Sandbox'
+    title = my_page.xpath(".//title/text()").get().strip()
+    assert title == "All products | Books to Scrape - Sandbox"
 
 
 def test_css(my_page):
-    title = my_page.css('title::text').get().strip()
-    assert title == 'All products | Books to Scrape - Sandbox'
+    title = my_page.css("title::text").get().strip()
+    assert title == "All products | Books to Scrape - Sandbox"
 
 
 def test_baseurl(my_page):
-    assert my_page.base_url == 'http://books.toscrape.com/index.html'
+    assert my_page.base_url == "http://books.toscrape.com/index.html"
 
 
 def test_urljoin(my_page):
-    assert my_page.urljoin("foo") == 'http://books.toscrape.com/foo'
+    assert my_page.urljoin("foo") == "http://books.toscrape.com/foo"
 
 
 def test_custom_baseurl():
@@ -56,7 +56,7 @@ def test_custom_baseurl():
     )
     page = MyPage(response=response)
 
-    assert page.url == 'http://www.example.com/path'
-    assert page.base_url == 'http://example.com/foo/'
-    assert page.urljoin("bar") == 'http://example.com/foo/bar'
+    assert page.url == "http://www.example.com/path"
+    assert page.base_url == "http://example.com/foo/"
+    assert page.urljoin("bar") == "http://example.com/foo/bar"
     assert page.urljoin("http://example.com/1") == "http://example.com/1"
