@@ -4,7 +4,7 @@ This package quite is similar to tests/po_lib_sub in terms of code contents.
 What we're ultimately trying to test here is to see if the `default_registry`
 captures the rules annotated in this module if it was not imported.
 """
-from typing import Dict, Any, Callable
+from typing import Any, Callable, Dict
 
 from url_matcher import Patterns
 
