@@ -1,13 +1,12 @@
-from .page_params import PageParams
+from .browser import BrowserHtml
 from .client import HttpClient
 from .http import (
     HttpRequest,
-    HttpResponse,
-    HttpRequestHeaders,
-    HttpResponseHeaders,
     HttpRequestBody,
+    HttpRequestHeaders,
+    HttpResponse,
     HttpResponseBody,
-    RequestUrl,
-    ResponseUrl
+    HttpResponseHeaders,
 )
-from .browser import BrowserHtml
+from .page_params import PageParams
+from .url import RequestUrl, ResponseUrl
